pub fn read_magic_bytes(path: &Path) -> SisterResult<[u8; 4]>Expand description
Helper: Read 4-byte magic from a file path.
Useful for sisters with binary formats to quickly identify files.
pub fn read_magic_bytes(path: &Path) -> SisterResult<[u8; 4]>Helper: Read 4-byte magic from a file path.
Useful for sisters with binary formats to quickly identify files.