Query trait for standard query interface.
All sisters support a flexible query interface that allows Hydra and other clients to query data uniformly.
Structs
- Query
- Standard query request.
- Query
Result - Query result.
- Query
Type Info - Information about a supported query type.
Traits
- Queryable
- Queryable trait that all sisters should implement.